@@ -1177,10 +1177,6 @@ func TestValidateISTUpdateWithWhitelister(t *testing.T) {
 				From:            &kapi.ObjectReference{Kind: "DockerImage", Name: "foo/bar:baz"},
 				ReferencePolicy: imageapi.TagReferencePolicy{Type: imageapi.LocalTagReferencePolicy},
 			},
-			expected: field.ErrorList{
-				field.Forbidden(field.NewPath("tag", "from", "name"),
-					`registry "docker.io:443" not allowed by whitelist: "example.com:*"`),
-			},
 		},
 
 		{
@@ -1409,13 +1405,6 @@ func TestValidateImageStreamImport(t *testing.T) {
 							},
 							ImportPolicy: imageapi.TagImportPolicy{Scheduled: true},
 						},
-						{
-							From: kapi.ObjectReference{
-								Kind: "DockerImage",
-								Name: "abc@sha256:3c87c572822935df60f0f5d3665bd376841a7fcfeb806b5f212de6a00e9a7b25",
-							},
-							ImportPolicy: imageapi.TagImportPolicy{Scheduled: true},
-						},
 						{
 							From: kapi.ObjectReference{
 								Kind: "ImageStreamTag",
@@ -1435,9 +1424,8 @@ func TestValidateImageStreamImport(t *testing.T) {
 			},
 			expected: field.ErrorList{
 				field.Invalid(field.NewPath("spec", "images").Index(1).Child("from", "name"), "abc@badid", "invalid reference format"),
-				field.Invalid(field.NewPath("spec", "images").Index(2).Child("from", "name"), "abc@sha256:3c87c572822935df60f0f5d3665bd376841a7fcfeb806b5f212de6a00e9a7b25", "only tags can be scheduled for import"),
-				field.Invalid(field.NewPath("spec", "images").Index(3).Child("from", "kind"), "ImageStreamTag", "only DockerImage is supported"),
-				field.Invalid(field.NewPath("spec", "images").Index(4).Child("from", "kind"), "ImageStreamImage", "only DockerImage is supported"),
+				field.Invalid(field.NewPath("spec", "images").Index(2).Child("from", "kind"), "ImageStreamTag", "only DockerImage is supported"),
+				field.Invalid(field.NewPath("spec", "images").Index(3).Child("from", "kind"), "ImageStreamImage", "only DockerImage is supported"),
 			},
 		},
 		"valid": {
@@ -1466,6 +1454,21 @@ func TestValidateImageStreamImport(t *testing.T) {
 			},
 			expected: field.ErrorList{},
 		},
+		"valid scheduled dockerimage sha/digest ref": {
+			namespace: "namespace",
+			name:      "foo",
+			specTags: map[string]imageapi.TagReference{
+				"tag": {
+					From: &kapi.ObjectReference{
+						Kind: "DockerImage",
+						Name: "abc@sha256:3c87c572822935df60f0f5d3665bd376841a7fcfeb806b5f212de6a00e9a7b25",
+					},
+					ImportPolicy: imageapi.TagImportPolicy{Scheduled: true},
+				},
+			},
+			statusTags: map[string]imageapi.TagEventList{},
+			expected:   field.ErrorList{},
+		},
 		"shortest name components": {
 			namespace: "f",
 			name:      "g",
